"
 File: Command.st
 Desc: Class for handling SQL commands (queries)
 Date: 06-FEB-2001
"

Object subclass: #Command
	instanceVariableNames: 'hConnection strQuery result'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Database'
!

Command class defineCFunc: 'mysqlQuery'
	withSelectorArgs: 'mysqlQuery: aHandle query: aString'
	returning: #int
	args: #(cObject string)
!

!Command class methodsFor: 'instance creation'!

new 
	| obj |
	obj := super new.
	obj connection: nil.
	obj query: ''.
	^ obj
!

connection: aHandle query: aString
	| obj |
	obj := Command new.
	obj connection: aHandle; query: aString.
	^ obj
! !

! Command methodsFor: 'accessors' !

connection
	^ hConnection
!
connection: aConnection
	hConnection := aConnection.
	^ self
!

query
	^ strQuery
!
query: aString
	strQuery := aString copy.
	^ self
!
result
	^ result
! !


!Command methodsFor: 'querying'!

execute

	(hConnection = nil)
		ifTrue: [self error: 'Invalid connection!'].
	(strQuery = nil)
		ifTrue: [self error: 'No query to execute!'].

	result := Command mysqlQuery: (hConnection handle) query: strQuery.
	(result ~= 0) ifTrue: [self raiseException].
	^ self
! !

!Command methodsFor: 'exceptions' !

raiseException
	self error: (hConnection getLastError)
! !

!Command class methodsFor: 'testing' !

test
	| c cmd str|
	str := 'insert into phone value ("","Kicha","91-427-447668")'.
	c := Connection host:'' user:'USER' pwd:'PASSWORD' db:'PHONE'.
	c open.
	(c valid) ifTrue: [
			cmd := c command: str.
			str printNl.
			cmd execute.
			cmd result printNl]
		  ifFalse: [ 'Connection failed!' printNl].
	c close
! ! 



