"
 File: Connection.st
 Desc: Abstraction for MySQL connection
 Date: 05-FEB-2001
"

DLD addModule: 'libmysql' !

Object subclass: #Connection
	instanceVariableNames: 'hMYSQL connected strHost strUser strPWD strDB'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Database'
!

Connection class defineCFunc: 'mysqlInit'
	withSelectorArgs: 'mysqlInit'
	returning: #cObject
	args: #()
!

Connection class defineCFunc: 'mysqlConnect'
	withSelectorArgs: 'mysqlConnect: aHandle host: aString user: aString pwd: aString db: aString'
	returning: #cObject
	args: #(cObject string string string string)
!

Connection class defineCFunc: 'mysqlDisconnect'
	withSelectorArgs: 'mysqlDisconnect: anObject'
	returning: #void
	args: #(cObject)
!

Connection class defineCFunc: 'mysqlError'
	withSelectorArgs: 'mysqlError: aHandle'
	returning: #string
	args: #(cObject)
!

Connection class defineCFunc: 'mysqlGetServerInfo'
	withSelectorArgs: 'mysqlGetServerInfo: aHandle'
	returning: #string
	args: #(cObject)
!

Connection class defineCFunc: 'mysqlGetHostInfo'
	withSelectorArgs: 'mysqlGetHostInfo: aHandle'
	returning: #string
	args: #(cObject)
!

Connection class defineCFunc: 'mysqlGetClientInfo'
	withSelectorArgs: 'mysqlGetClientInfo: aHandle'
	returning: #string
	args: #(cObject)
!

!Connection class methodsFor: 'instance creation'!

host: h user: u pwd: p db: d
	| obj hConn hConn2 |

	obj := self new.
	obj host: h; user: u; password: p; database: d.
	"hConn := Connection mysqlConnect: h user: u pwd: p db: d.
	(hConn = nil) 
		ifTrue: [ obj valid: false.
			  obj error: (Connection mysqlError: obj handle)].
			obj error: 'Connection attempt failed!'].
	obj handle: hConn; valid: true; database: d.
	"
	^obj
! ! 

!Connection methodsFor: 'connecting'!
open
	| hConn |
	hConn := Connection mysqlInit.
	hMYSQL := Connection mysqlConnect: hConn host: strHost user: strUser pwd: strPWD db: strDB.
	(hMYSQL = nil)
		ifTrue: [self handle: hConn; valid: false.
			self raiseException]
		ifFalse: [self valid: true].
	^ self
! !

!Connection methodsFor: 'exceptions'!

raiseException
	self error: (self getLastError)
!

getLastError
	^ Connection mysqlError: hMYSQL
!

!Connection methodsFor: 'accessing'!

handle
	^ hMYSQL.
!

handle: aHandle
	hMYSQL := aHandle.
	^ self
!
host
	^ strHost
!
host: aString
	strHost := aString copy.
	^ self
!

user
	^ strUser
!
user: aString
	strUser := aString copy.
	^ self
!
password
	^ strPWD
!
password: aString
	strPWD := aString copy.
	^ self
!
database
	^ strDB
!

database: aString
	strDB := aString copy.
	^ self
!

valid
	^ connected
!

valid: aBool
	connected := aBool.
	^ self
! !

!Connection methodsFor: 'mysql info'!

serverInfo
	^ Connection mysqlGetServerInfo: hMYSQL
!

hostInfo
	^ Connection mysqlGetHostInfo: hMYSQL
!

clientInfo
	^ Connection mysqlGetClientInfo: hMYSQL
! !

!Connection methodsFor: 'closing'!

close
	(connected = true)
		ifTrue: [Connection mysqlDisconnect: hMYSQL.
			 connected := false].
! !

!Connection methodsFor: 'finalization'!

finalize
	(connected = true)
		ifTrue: ['Closing' printNl.
			 self close].
! !

!Connection methodsFor: 'creating commands'!
command: aString
	| cmd |
	cmd := Command new.
	cmd connection: self; query: aString.
	^ cmd
! !

!Connection class methodsFor: 'testing' !

test
	| c |
	1 to: 100 do:  
		[:i | c := Connection host:'' user:'USER' pwd:'PASSWORD'
				db:'DATABASE'
			c open].

! !		
